@@ -1,24 +1,10 @@
 /*
+    SPDX-FileCopyrightText: 2001 The Kompany
+    SPDX-FileCopyrightText: 2002-2003 Ilya Konstantinov <kde-devel@future.shiny.co.il>
+    SPDX-FileCopyrightText: 2002-2003 Marcus Meissner <marcus@jet.franken.de>
+    SPDX-FileCopyrightText: 2003 Nadeem Hasan <nhasan@nadmm.com>
 
-    Copyright (C) 2001 The Kompany
-		  2002-2003	Ilya Konstantinov <kde-devel@future.shiny.co.il>
-		  2002-2003	Marcus Meissner <marcus@jet.franken.de>
-		  2003		Nadeem Hasan <nhasan@nadmm.com>
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "kamera.h"
@@ -40,10 +26,9 @@
 #include <KConfigGroup>
 #include "kameraconfigdialog.h"
 #include "kameradevice.h"
+#include "kcm_kamera_log.h"
 
-K_PLUGIN_CLASS_WITH_JSON(KKameraConfig, "kamera.json")
-
-Q_LOGGING_CATEGORY(KAMERA_KCONTROL, "kamera.kcontrol")
+K_PLUGIN_CLASS_WITH_JSON(KKameraConfig, "kcm_kamera.json")
 
 // --------------- Camera control center module widget ---
 
@@ -51,7 +36,7 @@ KKameraConfig::KKameraConfig(QWidget *parent, const QVariantList &)
     : KCModule(parent)
 {
 #ifdef DEBUG_KAMERA_KCONTROL
-    QLoggingCategory::setFilterRules(QStringLiteral("kamera.kcontrol.debug = true"));
+    QLoggingCategory::setFilterRules(QStringLiteral("kamera.kcm.debug = true"));
 #endif
     m_devicePopup = new QMenu(this);
 	m_actions = new KActionCollection(this);
